#
# spec file for package iozone
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define src_version 3
%define src_release 506
Name:           iozone
Version:        %{src_version}.%{src_release}
Release:        lp156.1.3
Summary:        Filesystem Benchmark
License:        SUSE-Freeware AND SUSE-Public-Domain AND GPL-2.0-or-later
URL:            https://www.iozone.org
Source0:        https://www.iozone.org/src/current/iozone%{src_version}_%{src_release}.tgz
Source1:        https://www.iozone.org/docs/Iozone_License.txt
Source2:        https://www.gnu.org/licenses/gpl-2.0.txt
BuildRequires:  dos2unix

%description
Filesystem benchmark tool. The benchmark tests file I/O performance for the following
operations: Read, write, re-read, re-write, read backwards, read strided,
fread, fwrite, random read, pread ,mmap, aio_read, aio_write.

%package doc
Summary:        Documentation how to use Iozone
BuildArch:      noarch

%description doc
This package contains the documentation for using and interpreting results of Iozone

%prep
%autosetup -n %{name}%{src_version}_%{src_release}

%build
%make_build -C src/current clean
%make_build CFLAGS="%{optflags} -DHAVE_PREADV -DHAVE_PWRITEV -fPIE" -C src/current linux

%install
install -D -p -m 0755 src/current/iozone %{buildroot}%{_bindir}/iozone
install -D -p -m 0755 src/current/fileop %{buildroot}%{_bindir}/fileop
install -D -p -m 0644 src/current/client_list %{buildroot}%{_datadir}/%{name}/client_list
install -D -p -m 0644 src/current/Generate_Graphs %{buildroot}%{_datadir}/%{name}/Generate_Graphs
install -D -p -m 0755 src/current/gengnuplot.sh %{buildroot}%{_datadir}/%{name}/gengnuplot.sh
install -D -p -m 0644 src/current/gnu3d.dem %{buildroot}%{_datadir}/%{name}/gnu3d.dem
install -D -p -m 0644 src/current/gnuplot.dem %{buildroot}%{_datadir}/%{name}/gnuplot.dem
install -D -p -m 0644 src/current/gnuplotps.dem %{buildroot}%{_datadir}/%{name}/gnuplotps.dem
install -D -p -m 0755 src/current/report.pl %{buildroot}%{_datadir}/%{name}/report.pl
install -D -p -m 0644 src/current/write_telemetry %{buildroot}%{_datadir}/%{name}/write_telemetry
install -D -p -m 0644 docs/iozone.1 %{buildroot}%{_mandir}/man1/iozone.1

chmod 644 src/current/Gnuplot.txt src/current/Changes.txt
dos2unix src/current/Gnuplot.txt
dos2unix %{buildroot}%{_datadir}/%{name}/report.pl
cp %{SOURCE1} Iozone_License.txt
cp %{SOURCE2} gpl-2.0.txt

%files
%license Iozone_License.txt
%doc src/current/Gnuplot.txt src/current/Changes.txt gpl-2.0.txt
%{_bindir}/fileop
%{_bindir}/iozone
%{_datadir}/%{name}/
%{_mandir}/man1/iozone.1%{?ext_man}

%files doc
%license Iozone_License.txt
%doc docs/*.pdf src/current/Changes.txt gpl-2.0.txt

%changelog
* Mon Jun  5 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to 3_506:
  * Fixed async with and without no copy.
- Update to 3_504:
  * Avoid terminating when some implementations return goofy values from aio_return() and/or aio_error().
- Update to 3_503:
  * Some design issues with async I/O that are now fixed.
- Update to 3_499:
  * Fix cases where stride goes beyond EOF, and also missing SC_AIO_MAX
- Update to 3_497:
  * Disable verify_buffer for async I/O as the buffer can change locations
    if the I/Os complete in a different order. Thus causing verify_buffer to get
    confused.
- Update to 3.494:
  * Add support for sparse files.
  detailed changelog at https://www.iozone.org/src/current/Changes.txt
* Sat Jul 23 2022 Dirk Müller <dmueller@suse.com>
- update to 3_493:
  * Improve the -+M option's compression pattern so that the achieved
    compressibility is closer to the value specifed in the -+a option.
  * Move memory allocation of main buffer to after the getopt, else
    the -S can cause issues later.
* Wed Jan 27 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Clean before starting to build (leftover *.o files may be present)
* Wed Jan 20 2021 Martin Pluskal <mpluskal@suse.com>
- Update to version 3_491:
  * Fix CFLAGS issue from Fedora maintainer.
* Wed Sep  2 2020 Dirk Mueller <dmueller@suse.com>
- update to 3.490:
  Fix gcc-10 warning about no-common.
  Fix compiler warning when HAVE_ANSIC is not defined
* Thu Jun 11 2020 Martin Pluskal <mpluskal@suse.com>
- Fix building with gcc10 by using -fcommon cflag
* Fri Jan  3 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 3_488:
  * mprove the Yates/Knuth method for shuffle.
* Sat Jan 12 2019 mardnh@gmx.de
- Update to version 3_483:
  * Adding -+M (special dedupe layout)
  * Adding -+a (set compression in special layout)
  * Adding -+Q (set dedupe granule size in special layout)
  * Cleanup compiler warnings.
  * Bug fix code in special_gen_new_buf..
  * Bug fix code in special_gen_new_buf.. More copies of the other
    bug.
  * Bug fix code in special_gen_new_buf.. needed (*op ==0) in one
    more line.
  * Add -+R option to specify the file names are in a file.
  * Fix help menu for -+R option.  It does not also use -F
  * Bug fix for case of -H where gcc seems to think the size of
    long long.
    is != size of off64_t
  * Bug fix for prototype mismatch in async_write_no_copy.
* Fri Oct  6 2017 mpluskal@suse.com
- Update to version 3_471:
  * Fix error messages to use the correct file name from
    dummyfile[xx] instead of "filename" in the thread tests.
  * Fix compiler warning from Clang on MacOS for mythread_create().
    Prototype didn't match the formal function definition.
  * Switch to IOZ_macosx everywhere for compatibility with
    Mountain Lion.
  * Increase MAXSTREAMS to 1024. Systems have more power today
    than 20+ years ago.
  * Make -+W -+C -+y use a flag instead of its option value to
    indiate its usage.
* Sat Aug 27 2016 mpluskal@suse.com
- Update to version 3_465:
  * Some BSD changes to avoid compiler complaints.
  * Make sure we don't have missing prototypes.
  * Add support for building targets with NO_SIGNAL, NO_FORK, NO_SOCKET
  * Fix missing typedef in FreeBSD.
  * Fix typeoh in spelling of DragonFly.
  * Make the sighandler_t change effective for all BSD derivatives.
  * Make the my_sig_t change effective for all BSD derivatives.
  * Unify the usage of __FreeBSD__
  * Build on BSD 10.3 without warnings.  Clang compilers.
  * Make more friendly to build on Solaris.
* Mon Jul  4 2016 mpluskal@suse.com
- Filter -Wall from optflags to prevent post-build check failure:
  * no-return-in-nonvoid-function libbif.c:175, 224, 256,343, 386,
    402
  * license does not allow us to modify sources
  * reported issues seems harlmess in case of io benchmark
* Sat Jul  2 2016 mpluskal@suse.com
- Update to version 3_444:
  * Cleanup 64 bit compiles.
  * Code cleanup for all of the un-needed void * maddness.
  * Code cleanup for casting consistency and *&(^&*( compiler
    warnings !!!
  * Code cleanup for casting consistency
* Fri Feb  5 2016 mpluskal@suse.com
- Update to 3_434
  * Adding code from Alexey Skidanov. Pthread burst I/O.
- Build with optflags
- Enable PREADV and PWRITEV
- Minor spec file cleanups
- Fix typo in changelog
* Wed Jan 14 2015 mpluskal@suse.com
- Update license information
* Tue Jan 13 2015 mpluskal@suse.com
- update to version 3_430
  * Add two more characters to array my_port_num.
  * Adding -+b option for bursty operations.
- split documentation to separate package
* Wed Jul 30 2014 dsterba@suse.cz
- update to version 3_428
  * Minor bug fix for -J option (think time) in the thread_pread_test()
  * Add -+J option. Include think time (-j #) in throughput calculation
  * Add better handling of exit values.
  * Add new contributor to list.
  * Bug fix from Alp Aker:
  * Patch for a minor issue in IOzone's signal_handler() function
  * Improve consistency of Kbytes instead of kbytes, KBytes, kBytes...
  * Fix for 64 bit and touch_dedup.
  * Fix for 64 bit and gen_new_buf
  * Adjust formatting so fields don't run together.
- clean spec
* Mon Feb  4 2013 bahid@emc.com
- update to version 3_414 (3_283 in Benchmark:/Filesystem)
  * Add O_DIRECT for Windows
  * Add -+w dedup testing mode.
  * Make remaining non-dedup data unique.
  * Make non-dedupable more unique.
  * Bug fix for non-dedup.
  * Make random offsets unique, using Knuth shuffle.
  * free memory used for random offset uniqueness.
  * Make unique/random offsets 64bits.
  * Add fallback for random/unique.
  * Make non-dedup region more unique
  * Add -+y ## to set percentage of interior dedup.
  * Bug fixes for -+w and -+y
  * Minor fix for dedup
  * Adding -+C to set percent of dedupable within a file.
  * Add solaris to read sync O_RSYNC
  * Add space to avoid field output touching each other.
  * Add check for config file exceeding MAXSTREAMS.
  * Add new contributor's name.
  * Bug fix. rewrite_rec needed to fill entire buffer, or later stride read will fail.
  * Add ability for remote clients to return errors to the master and have the master display on output.
  * fix double reporting of client errors
  * Eliminate extra file descriptor in fwrite test.
  * bug fix for barray allocation in -T mode
  * Changes from Debian: Retry umount, add fileop for linux-sparc, and
  * fix column width in fileop for faster boxes.
  * Add O_DIRECT support to FreeBSD
  * Fix for defines in FreeBSD
  * Add IMON_SYNC to enable monitor scripts to be run sync.
  * Add directio() for Solaris
  * Add fixes for unresolved references in directio() for Solaris
  * Fix c++ style comment back to 'C' style comment.
  * Bug fix for check_filenames and large files
  * Replace tripple rand() calls with 64 bit Mersene twister.
  * Add read-only, external file, with no-verify. -+E
  * Permit -+E on dedup files.
  * Permit -+E on random read only testing, on existing file.
  * Add passing master listener's port to remote children if it is not HOST_LIST_PORT
  * Adding Dave Boone's notruncate option -+N
  * Bug fix for Dave's code.
  * Add multi -t ops. Fabrice
  * Added Li Qin's multi dedup set support. -+S #
  * Bug fix for -+S dedup_mseed needs to be an integer
  * Make -+S generate more uniqueness
  * Bug fix for -+S
  * Make umount/remount more robust, in the face of server errors.
  * Improve the help string for the -+S option.
  * Add new contributor name.
  * Add support for the programmable interdimensional timer.
  * Bug fix for PIT on remote clients.
  * Have children re-acquire get_resolution.
  * Bug fix for t_range addition.
  * Get rid of a warning. ( An invalid warning, but none the less )
  * Add more words to the usage warnings and license
  * Remove Ascii dependency for IBM's Z/OS that speaks EBCDIC.
  * Add support for SUA
  * Remove Sanity check so that SMB on Windows, under SUA, works
  * Cache the getaddrinfo call.
  * delete optimization.. bad...Cache the getaddrinfo call.
  * Change pit to use unsigned long longs
  * Add Linux processor affinity
  * Remove UDP usage
  * Increment protocol_version to catch incompat versions.
  * Fixup for new include needed by Solaris10
  * Patch for Mac errno
  * Patch for Mac printf's
  * Fix Josh's introduction of new Linux warnings.
  * Take sleep(1) out put path, deal with it in error/retry path
  * Add -+z latency histogram logging.
  * Format change for the -+z latency histogram logging.
  * Added -+O Op_rate control.
  * Close race condition with master closing socket to child async reader
  * Add "mygen" generation to the remote children protocol.
  * Set Listen(s,100) to Listen(s,MAXSTREAMS)
  * Move lable "again" to outside of cdebug.
  * More fixes for busted crap in Solaris !!!
  * AIX update. They now have errno.h
  * Need errno.h for FreeBSD
  * Need to include errno.h for Cygwin
  * Add SO_LINGER for master_listen and child_listen
  * Fix for linger addition
  * Make linger for all
  * Change sleep() calls, that help connect() to nanosleep() calls.
  * Fixup remainder for nanosleep()
  * Add code for pread/pwrite from Ben England (Redhat)
  * Add code for MDEBUG and CDEBUG from Bob England (Redhat)
  * Add code for building HPUX. Errno.h
  * Fixes for Windows (nanosleep doesn't always work )
  * Fixes for preadv and pwritev from RedHat (Ben Englanc)
  * Add warnings for default switch cases, and exit with value for unknowns.
  * Fix warnings from RedHat patches
  * Bug fix for getopt default case, with bad parameter handed in.
  * Adding thread_read_test and thread_write_test.
  * bug fix for re-write rec.
  * Mods for DragonFly support.
  * Add -+W to permit chid_skew.
  * Reduce CPU consumption in the op_rate control mechanism.
  * Increase buffer size for configuration lines.
  * Bug fix for clobbering of buffer. "tfile" needed to be bigger
  * Bug fix for using -m in combination with -+d
  * Bug fix: Improve consistency of use_thread in thread_fread and thread_fwrite
  * Compat fix: Move from using macosx to IOZ_macosx
  * Adding -+F flag for trunc before thread_write.
  * Bug fix for -+F flag.
* Thu Mar 29 2007 jblunck@suse.de
- initial package
